A dataset containing metadata for countries included in DHS surveys, including standardized country codes across multiple international organizations.
DHS.country.metaA data frame with 60 rows and 12 columns:
Country code used by UNAIDS.
Name of the subregion (e.g., West Africa, South Asia).
Country code used by WHO.
Country code used by FIPS.
Country code used by UNICEF.
Name of the global region (e.g., Africa, Asia).
Two-letter ISO country code.
Three-letter ISO country code.
Numeric ordering of the region for visualization.
Unique country code assigned by DHS.
Full name of the country.
Country code used by UN Statistics Division.