A dataset containing the original 22 health and demographic indicators supported in the app.
ref_tab_22A data frame with 22 rows and 13 columns:
Unique identifier for the indicator.
Short label for the indicator.
Detailed definition of the indicator.
General category or theme of the indicator.
Abbreviation of the chapter where the indicator appears.
Logical. Whether the indicator is available in the Individual Recode dataset.
Logical. Whether the indicator is available in the Household Members dataset.
Logical. Whether the indicator is available in the Children's Recode dataset.
Logical. Whether the indicator is available in the Birth Recode dataset.
Logical. Whether the indicator is available in the Household Recode dataset.
Logical. Whether the indicator is available in the Men's Recode dataset.
Logical. Whether the indicator is available in the AIDS Indicator Survey dataset.
Logical. Whether the indicator is available in the Couple's Recode dataset.